<?php
/*
Plugin Name: Private Suite
Plugin URI: http://sillybean.net/code/wordpress/private-suite/
Description: Allows admins to add private pages to <code>wp_list_pages()</code>, <code>wp_page_menu()</code>, and the Pages widget or use a separate <code>wp_list_private_pages()</code> tag; specify the prefix on private and password-protected titles; create private categories; and choose which user roles may read private pages and posts.
Version: 1.1
Author: Stephanie Leary
Author URI: http://sillybean.net/

Changelog:
= 1.1 =
* Fixed list markup when forcing private pages to appear in page lists (Thanks, Tina and Sébastien!)
* French translation by Regis (August 5, 2010)
= 1.01 =
* Fixed bug that caused conflicts with other plugins' widgets.
* Fixed formatting of category checkboxes on the options page. (January 24, 2010)
= 1.0 = 
* New `wp_list_private_pages()` tag. 
* Fixed markup (somewhat) when adding private pages to existing template tags.
* Added private pages to parent dropdown when editing pages.
* Added page widget that includes private pages.
* Added private categories feature.
* Fixed prefix fields to work with HTML (e.g. <img> tags)
* Translation support. (January 16, 2010)
= 0.9 = 
* First release (October 15, 2009)

Copyright 2009  Stephanie Leary  (email : steph@sillybean.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// first of all...
private_suite_set_roles();

// Hook for adding admin menus
add_action('admin_menu', 'private_suite_add_options_page');

// set default options
function private_suite_activate() { 
	 $options = private_suite_set_defaults();
	 add_option('private_suite', $options, '', 'yes');
	 private_suite_set_roles();
}
register_activation_hook( __FILE__, 'private_suite_activate' );

// defaults
function private_suite_set_defaults() {
	return array(
		'read_posts' => 'editor',
		'edit_posts' => 'editor',
		'delete_posts' => 'editor',
		'read_pages' => 'editor',
		'edit_pages' => 'editor',
		'delete_pages' => 'editor',
		'private_title_prefix' => __("Private: ", 'private-suite'),
		'protected_title_prefix' => __("Protected: ", 'private-suite'), 
		'private_suite_filter' => 0,
		'categories' => 0
	);	
}

// Add link to options from plugin list
function private_suite_plugin_actions($links, $file) {
	if ($file == 'private-suite/private-suite.php' && function_exists("admin_url")) {
 		$settings_link = '<a href="' . admin_url('options-general.php?page=private-suite') . '">' . __('Settings', 'private-suite') . '</a>';
		array_unshift($links, $settings_link); 
	}
	return $links;
}
add_filter('plugin_action_links', 'private_suite_plugin_actions', 10, 2);

// add our options page
function private_suite_add_options_page() {
    // Add a new submenu under Options:
	add_options_page(__('Private Suite', 'private-suite'), __('Private Suite', 'private-suite'), 8, 'private-suite', 'private_suite_options');
	$options = private_suite_set_defaults();
	add_option('private_suite', $options, '', 'yes');
}

/*------------------------ Set Roles ------------------------*/

// allow chosen roles to read, edit, and delete private posts and pages
function private_suite_set_roles() {
	$options = get_option('private_suite');
	if (empty($options)) $options = private_suite_set_defaults();
	
	$read_pages_role = get_role( $options['read_pages'] );
	$read_pages_role->add_cap( 'read_private_pages' );
	
	$edit_pages_role = get_role( $options['edit_pages'] );
	$edit_pages_role->add_cap( 'edit_private_pages' );
	
	$delete_pages_role = get_role( $options['delete_pages'] );
	$delete_pages_role->add_cap( 'delete_private_pages' );
	
	$read_posts_role = get_role( $options['read_posts'] );
	$read_posts_role->add_cap( 'read_private_posts' );
	
	$edit_posts_role = get_role( $options['edit_posts'] );
	$edit_posts_role->add_cap( 'edit_private_posts' );
	
	$delete_posts_role = get_role( $options['delete_posts'] );
	$delete_posts_role->add_cap( 'delete_private_posts' );
}

/*------------------------ Set Prefixes ------------------------*/

// remove the default "Private: " page title prefix and add whatever the user wants
add_filter('private_title_format', 'private_suite_custom_private_title');

function private_suite_custom_private_title($s) {
	$options = get_option('private_suite');
	$s = str_replace(__("Private: ", 'private-suite'), '', $s);
	return stripslashes($options['private_title_prefix']).$s;
}

// remove the default "Protected: " page title prefix and add whatever the user wants
add_filter('protected_title_format', 'private_suite_custom_protected_title');

function private_suite_custom_protected_title($s) {
	$options = get_option('private_suite');
	$s = str_replace(__("Protected: ", 'private-suite'), '', $s);
	return stripslashes($options['protected_title_prefix']).$s;
}

/*---------------------- Private Categories -----------------------*/

add_action('save_post', 'set_private_categories');

function set_private_categories($postid) {
	global $wpdb;
	if ($parent_id = wp_is_post_revision($postid)) 
		$postid = $parent_id;
	$options = get_option('private_suite');
	$privatecats = $options['categories'];
	if (!is_array($privatecats)) 
		$privatecats = array($privatecats);
	foreach ($privatecats as $cat) {
		if (in_category($cat, $postid)) {
			// wp_update_post() calls the save_post action again and could create an infinite loop, so we'll use the brute force method...
			$wpdb->query( $wpdb->prepare("UPDATE $wpdb->posts SET `post_status` = %s WHERE ID = %d AND `post_status` = %s", 'private', (int)$postid, 'publish') );
		}
	}
}

/*------------------------ Fix Page Lists ------------------------*/

// wp_list_private_pages();

function walk_private_pages() {
	$walker = new Private_Page_Walker;
	$args = func_get_args();
	return call_user_func_array(array(&$walker, 'walk'), $args);
}

class Private_Page_Walker extends Walker {
	var $tree_type = 'page';
	var $db_fields = array ('parent' => 'post_parent', 'id' => 'ID'); //TODO: decouple this

	function start_lvl(&$output, $depth) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class='subpage'>\n";
	}

	function end_lvl(&$output, $depth) {
		$indent = str_repeat("\t", $depth);
		$output .= "$indent</ul>\n";
	}

	function start_el(&$output, $page, $depth, $current_page, $args) {
		if ( $depth )
			$indent = str_repeat("\t", $depth);
		else
			$indent = '';

		extract($args, EXTR_SKIP);
		$css_class = 'private page_item page-item-'.$page->ID;
		if ( !empty($current_page) ) {
			$_current_page = get_page( $current_page );
			if ( in_array($page->ID, (array) $_current_page->ancestors) )
				$css_class .= ' current_page_ancestor';
			if ( $page->ID == $current_page )
				$css_class .= ' current_page_item';
			elseif ( $_current_page && $page->ID == $_current_page->post_parent )
				$css_class .= ' current_page_parent';
		}
		
		$output .=  $indent . '<li class="' . $css_class . '"><a href="' . get_page_link($page->ID) . '" title="' . 
			attribute_escape(apply_filters('the_title', $page->post_title)) . '">' . apply_filters('the_title', $page->post_title) . '</a>';

		if ( !empty($show_date) ) {
			if ( 'modified' == $show_date )
				$time = $page->post_modified;
			else
				$time = $page->post_date;

			$output .= " " . mysql2date($date_format, $time);
		}
	}

	function end_el(&$output, $page, $depth) {
		$output .= "</li>\n";
	}
}

function wp_list_private_pages($args = '') {
      $defaults = array(
      'depth' => 0, 'show_date' => '',
      'date_format' => get_option('date_format'),
      'child_of' => 0, 'exclude' => '',
      'title_li' => '',
	  'echo' => 1,
      'authors' => '', 'sort_column' => 'menu_order, post_title',
      'link_before' => '', 'link_after' => ''
      );

     $r = wp_parse_args( $args, $defaults );
      extract( $r, EXTR_SKIP );

     $output = '';
      $current_page = 0;

      // sanitize, mostly to keep spaces out
     $r['exclude'] = preg_replace('[^0-9,]', '', $r['exclude']);

     // Allow plugins to filter an array of excluded pages
    $r['exclude'] = implode(',', apply_filters('wp_list_pages_excludes', explode(',', $r['exclude'])));

      // Query pages.
    $r['hierarchical'] = 1;
     $pages = private_suite_get_pages($r);

     if ( !empty($pages) ) {
         if ( $r['title_li'] )
             $output .= '<li class="pagenav">' . $r['title_li'] . '<ul>';

        global $wp_query;
        if ( is_page() || $wp_query->is_posts_page )
             $current_page = $wp_query->get_queried_object_id();
         $output .=  walk_private_pages($pages, $r['depth'], $current_page, $r);

         if ( $r['title_li'] )
              $output .= '</ul></li>';
      }

	  remove_filter('wp_list_pages', 'wp_list_private_pages'); // prevent infinite loop
      $output = apply_filters('wp_list_pages', $output);

     if ( $r['echo'] )
         echo $output;
    else
          return $output;
}

function &private_suite_get_pages($args = '') {				// PATCHED get_pages() BASED ON TRAC #8592
	global $wpdb, $user_ID;

	$defaults = array(
		'child_of' => 0, 'sort_order' => 'ASC',
		'sort_column' => 'post_title', 'hierarchical' => 1,
		'exclude' => '', 'include' => '',
		'meta_key' => '', 'meta_value' => '',
		'authors' => '', 'parent' => -1, 'exclude_tree' => '',
		'number' => '', 'offset' => 0
	);

	$r = wp_parse_args( $args, $defaults );
	extract( $r, EXTR_SKIP );
	$number = (int) $number;
	$offset = (int) $offset;

	$cache = array();
	$key = md5( serialize( compact(array_keys($defaults)) ) );
	if ( $cache = wp_cache_get( 'get_pages', 'posts' ) ) {
		if ( is_array($cache) && isset( $cache[ $key ] ) ) {
			$pages = apply_filters('get_pages', $cache[ $key ], $r );
			return $pages;
		}
	}

	if ( !is_array($cache) )
		$cache = array();

	$inclusions = '';
	if ( !empty($include) ) {
		$child_of = 0; //ignore child_of, parent, exclude, meta_key, and meta_value params if using include
		$parent = -1;
		$exclude = '';
		$meta_key = '';
		$meta_value = '';
		$hierarchical = false;
		$incpages = preg_split('/[\s,]+/',$include);
		if ( count($incpages) ) {
			foreach ( $incpages as $incpage ) {
				if (empty($inclusions))
					$inclusions = $wpdb->prepare(' AND ( ID = %d ', $incpage);
				else
					$inclusions .= $wpdb->prepare(' OR ID = %d ', $incpage);
			}
		}
	}
	if (!empty($inclusions))
		$inclusions .= ')';

	$exclusions = '';
	if ( !empty($exclude) ) {
		$expages = preg_split('/[\s,]+/',$exclude);
		if ( count($expages) ) {
			foreach ( $expages as $expage ) {
				if (empty($exclusions))
					$exclusions = $wpdb->prepare(' AND ( ID <> %d ', $expage);
				else
					$exclusions .= $wpdb->prepare(' AND ID <> %d ', $expage);
			}
		}
	}
	if (!empty($exclusions))
		$exclusions .= ')';

	$author_query = '';
	if (!empty($authors)) {
		$post_authors = preg_split('/[\s,]+/',$authors);

		if ( count($post_authors) ) {
			foreach ( $post_authors as $post_author ) {
				//Do we have an author id or an author login?
				if ( 0 == intval($post_author) ) {
					$post_author = get_userdatabylogin($post_author);
					if ( empty($post_author) )
						continue;
					if ( empty($post_author->ID) )
						continue;
					$post_author = $post_author->ID;
				}

				if ( '' == $author_query )
					$author_query = $wpdb->prepare(' post_author = %d ', $post_author);
				else
					$author_query .= $wpdb->prepare(' OR post_author = %d ', $post_author);
			}
			if ( '' != $author_query )
				$author_query = " AND ($author_query)";
		}
	}

	$join = '';
	$where = "$exclusions $inclusions ";
	if ( ! empty( $meta_key ) || ! empty( $meta_value ) ) {
		$join = " LEFT JOIN $wpdb->postmeta ON ( $wpdb->posts.ID = $wpdb->postmeta.post_id )";

		// meta_key and meta_value might be slashed
		$meta_key = stripslashes($meta_key);
		$meta_value = stripslashes($meta_value);
		if ( ! empty( $meta_key ) )
			$where .= $wpdb->prepare(" AND $wpdb->postmeta.meta_key = %s", $meta_key);
		if ( ! empty( $meta_value ) )
			$where .= $wpdb->prepare(" AND $wpdb->postmeta.meta_value = %s", $meta_value);

	}

	if ( $parent >= 0 )
		$where .= $wpdb->prepare(' AND post_parent = %d ', $parent);

	$query = "SELECT * FROM $wpdb->posts $join WHERE (post_type = 'page'";					/* ----------- patch ----------- */ 
 	$where .= " AND (post_status = 'publish'"; 
 	if ( is_admin() ) 
 	        $where .= " OR post_status = 'future' OR post_status = 'draft' OR post_status = 'pending'"; 
 	if ( is_user_logged_in() ) { 
 	        $where .= current_user_can( "read_private_pages" ) ? " OR post_status = 'private'" : " OR post_author = $user_ID AND post_status = 'private'"; 
 	} 
 	$where .= ')'; 
 	        
 	$query .= " $where )" . $author_query; 
	$query .= " ORDER BY " . $sort_column . " " . $sort_order ;

	if ( !empty($number) )
		$query .= ' LIMIT ' . $offset . ',' . $number;

	$pages = $wpdb->get_results($query);

	if ( empty($pages) ) {
		$pages = apply_filters('get_pages', array(), $r);
		return $pages;
	}

	// Sanitize before caching so it'll only get done once
	$num_pages = count($pages);
	for ($i = 0; $i < $num_pages; $i++) {
		$pages[$i] = sanitize_post($pages[$i], 'raw');
	}

	// Update cache.
	update_page_cache($pages);

	if ( $child_of || $hierarchical )
		$pages = & get_page_children($child_of, $pages);

	if ( !empty($exclude_tree) ) {
		$exclude = (int) $exclude_tree;
		$children = get_page_children($exclude, $pages);
		$excludes = array();
		foreach ( $children as $child )
			$excludes[] = $child->ID;
		$excludes[] = $exclude;
		$num_pages = count($pages);
		for ( $i = 0; $i < $num_pages; $i++ ) {
			if ( in_array($pages[$i]->ID, $excludes) )
				unset($pages[$i]);
		}
	}

	$cache[ $key ] = $pages;
	wp_cache_set( 'get_pages', $cache, 'posts' );

	$pages = apply_filters('get_pages', $pages, $r);

	return $pages;
}

/*----------------- Add to existing page lists -----------------*/

// add private pages to page list
$options = get_option('private_suite');
if ($options['private_suite_filter'])
	add_filter('wp_list_pages', 'private_suite_add_menu');

function private_suite_add_menu($output) {
	// adapted from Branko Ajzele:
	// http://activecodeline.com/create-a-menu-for-private-pages-and-posts-in-wordpress
	if (current_user_can('read_private_pages')) {
		global $wpdb;
		$list = '';
		$pages = $wpdb->get_results("SELECT id, post_title, post_parent FROM $wpdb->posts WHERE post_status='private' AND post_type='page'");	
		foreach ($pages as $page) {
			if ($page->post_parent == 0) {
				// if this is a new parent item & we have already print one, close the old one
				if (isset($tina_parent) && $tina_parent > 0) {
					$list .= '</ul>';
					$tina_parent = 0;
				}
				$list .= '<li class="page_item private tmg"><a href="'.get_permalink($page->id). '" title="">'. $page->post_title .'</a>';
				$tina_parent = 1;
			} else { // tina fixed this 5/3/2010
				if (isset($tina_parent) && $tina_parent == 1) {
					$list .= '<ul class="children tmg">';
					$tina_parent = $tina_parent + 1;
				}
				$list .= '<li class="page_item private tmg"><a href="'.get_permalink($page->id). '" title="">'. $page->post_title .'</a></li>';
			}
		}
			if (isset($tina_parent) && $tina_parent > 1) {
				$list .= "</ul></li>";
			} else {
				$list .= "</li>";
			}
		$output = preg_replace ('/<\/ul>$/', "$list</ul>", $output); // remove '</ul></li>' from the end
		return $output.$list; // append our extra list items 
	}
	else return $output;
}

/*---------------------- Page Widget ---------------------------*/
//*
class WP_Widget_Private_Pages extends WP_Widget {

	function WP_Widget_Private_Pages() {
		$widget_ops = array('classname' => 'widget_private_pages', 'description' => __( 'Your blog&#8217;s WordPress Pages, including the private ones', 'private-suite') );
		$this->WP_Widget('private_pages', __('Pages (with private)', 'private-suite'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __( 'Pages' , 'private-suite') : $instance['title']);
		$sortby = empty( $instance['sortby'] ) ? 'menu_order' : $instance['sortby'];
		$exclude = empty( $instance['exclude'] ) ? '' : $instance['exclude'];

		if ( $sortby == 'menu_order' )
			$sortby = 'menu_order, post_title';

		$out = wp_list_private_pages( apply_filters('widget_pages_args', array('title_li' => '', 'echo' => 0, 'sort_column' => $sortby, 'exclude' => $exclude) ) );

		if ( !empty( $out ) ) {
			echo $before_widget;
			if ( $title)
				echo $before_title . $title . $after_title;
		?>
		<ul>
			<?php echo $out; ?>
		</ul>
		<?php
			echo $after_widget;
		}
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( in_array( $new_instance['sortby'], array( 'post_title', 'menu_order', 'ID' ) ) ) {
			$instance['sortby'] = $new_instance['sortby'];
		} else {
			$instance['sortby'] = 'menu_order';
		}

		$instance['exclude'] = strip_tags( $new_instance['exclude'] );

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'sortby' => 'post_title', 'title' => '', 'exclude' => '') );
		$title = esc_attr( $instance['title'] );
		$exclude = esc_attr( $instance['exclude'] );
	?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('sortby'); ?>"><?php _e( 'Sort by:'); ?></label>
			<select name="<?php echo $this->get_field_name('sortby'); ?>" id="<?php echo $this->get_field_id('sortby'); ?>" class="widefat">
				<option value="post_title"<?php selected( $instance['sortby'], 'post_title' ); ?>><?php _e('Page title'); ?></option>
				<option value="menu_order"<?php selected( $instance['sortby'], 'menu_order' ); ?>><?php _e('Page order'); ?></option>
				<option value="ID"<?php selected( $instance['sortby'], 'ID' ); ?>><?php _e( 'Page ID'); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('exclude'); ?>"><?php _e( 'Exclude:'); ?></label> <input type="text" value="<?php echo $exclude; ?>" name="<?php echo $this->get_field_name('exclude'); ?>" id="<?php echo $this->get_field_id('exclude'); ?>" class="widefat" />
			<br />
			<small><?php _e( 'Page IDs, separated by commas.'); ?></small>
		</p>
<?php
	}
}

function private_suite_widgets_init() {
	register_widget('WP_Widget_Private_Pages');
}

add_action('widgets_init', 'private_suite_widgets_init');
/**/
/*-------------------- Fix Page Dropdowns ----------------------*/

add_filter('wp_dropdown_pages','replace_dropdown_private_pages');

function replace_dropdown_private_pages($output) {
	return wp_dropdown_private_pages(array(
			'exclude_tree' => $post->ID, 'selected' => $post->post_parent, 
			'name' => 'parent_id', 'show_option_none' => __('Main Page (no parent)'), 'sort_column'=> 'menu_order, post_title',
           'depth' => 0, 'child_of' => 0,
           'echo' => 0,
           'show_option_no_change' => '',
           'option_none_value' => ''
       ));
}

//*
function wp_dropdown_private_pages($args = '') {
		global $post;
       $defaults = array(
			'exclude_tree' => $post->ID, 'selected' => $post->post_parent, 
			'name' => 'parent_id', 'show_option_none' => __('Main Page (no parent)'), 'sort_column'=> 'menu_order, post_title',
           'depth' => 0, 'child_of' => 0,
           'echo' => 0,
           'show_option_no_change' => '',
           'option_none_value' => ''
       );
       
	   $r = array_merge( $args, $defaults );
       extract( $r, EXTR_SKIP );
   
       $pages = private_suite_get_pages(array('exclude_tree' => $post->ID));
       $output = '';
       $name = esc_attr($name);
   
       if ( ! empty($pages) ) {
           $output = "<select name=\"$name\" id=\"$name\">\n";
          if ( $show_option_no_change )
              $output .= "\t<option value=\"-1\">$show_option_no_change</option>";
          if ( $show_option_none )
               $output .= "\t<option value=\"$option_none_value\">$show_option_none</option>\n";
           $output .= walk_page_dropdown_tree($pages, 0, $r);
           $output .= "</select>\n";
       }
   
   		remove_filter('wp_dropdown_pages','replace_dropdown_private_pages');	// prevent infinite loop
       	$output = apply_filters('wp_dropdown_pages', $output);
   
       if ( $echo )
           echo $output;
   
       return $output;
   }
/**/


/*------------------------ Deactivation ------------------------*/

// when deactivated, return roles to normal
register_deactivation_hook( __FILE__, 'private_suite_remove_options' );

function private_suite_remove_options() {
	private_suite_reset_roles();
	delete_option('private_suite');
}

// return roles to normal
function private_suite_reset_roles() {
	$options = get_option('private_suite');
	// remove all
	$read_pages_role = get_role( $options['read_pages'] );
	$read_pages_role->remove_cap( 'read_private_pages' );
	$edit_pages_role = get_role( $options['edit_pages'] );
	$edit_pages_role->remove_cap( 'edit_private_pages' );
	$delete_pages_role = get_role( $options['delete_pages'] );
	$delete_pages_role->remove_cap( 'delete_private_pages' );
	$read_posts_role = get_role( $options['read_posts'] );
	$read_posts_role->remove_cap( 'read_private_posts' );
	$edit_posts_role = get_role( $options['edit_posts'] );
	$edit_posts_role->remove_cap( 'edit_private_posts' );
	$delete_posts_role = get_role( $options['delete_posts'] );
	$delete_posts_role->remove_cap( 'delete_private_posts' );
	// give it back to editors
	$editor = get_role( 'editor' );
	$editor->add_cap( 'read_private_pages' );
	$editor->add_cap( 'edit_private_pages' );
	$editor->add_cap( 'delete_private_pages' );
	$editor->add_cap( 'read_private_posts' );
	$editor->add_cap( 'edit_private_posts' );
	$editor->add_cap( 'delete_private_posts' );
	// give it back to admins
	$admin = get_role( 'administrator' );
	$admin->add_cap( 'read_private_pages' );
	$admin->add_cap( 'edit_private_pages' );
	$admin->add_cap( 'delete_private_pages' );
	$admin->add_cap( 'read_private_posts' );
	$admin->add_cap( 'edit_private_posts' );
	$admin->add_cap( 'delete_private_posts' );
}

/*------------------------ Options Forms ------------------------*/

function private_suite_options() {
	if ( current_user_can('manage_options') ) {  
	// variables for the field and option names 
		$hidden_field_name = 'private_suite_submit_hidden';
	
		// See if the user has posted us some information
		// If they did, this hidden field will be set to 'Y'
		if( $_POST[ $hidden_field_name ] == 'Y' ) {
			private_suite_reset_roles();
			// Save the posted value in the database
			$options = array();
			$options['private_suite_filter'] = $_POST['private_suite_filter'];
			$options['read_posts'] = $_POST['read_posts'];
			$options['edit_posts'] = $_POST['edit_posts'];
			$options['delete_posts'] = $_POST['delete_posts'];
			$options['read_pages'] = $_POST['read_pages'];
			$options['edit_pages'] = $_POST['edit_pages'];
			$options['delete_pages'] = $_POST['delete_pages'];
			$options['private_title_prefix'] = $_POST['private_title_prefix'];
			$options['protected_title_prefix'] = $_POST['protected_title_prefix'];
			$options['categories'] = $_POST['post_category'];
			
			update_option('private_suite', $options);
			//update_option('blog_public', $_POST['blog_public']);
			// Put an options updated message on the screen
	?>
	<div class="updated"><p><strong><?php _e('Options saved.'); ?></strong></p></div>
    
	<?php  } // Now display the options editing screen ?>
	
    <div class="wrap">
	<form method="post" id="private_suite_form">
    <?php wp_nonce_field('update-options'); ?>
    <?php $options = get_option('private_suite'); ?>
    
    <h2><?php _e( 'Private Suite Options', 'private-suite'); ?></h2>
	<input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">
    
    <div style="float: left; width: 40%; margin-right: 5%;">
        
    <p><label for="private_title_prefix"><?php _e( 'Prefix for private post and page titles:' , 'private-suite'); ?></label><br />
	<input type="text" style="width: 27em;" id="private_title_prefix" name="private_title_prefix" value="<?php echo stripslashes(htmlentities($options['private_title_prefix'])); ?>" /></p>
    <p><label for="protected_title_prefix"><?php _e( 'Prefix for password-protected post and page titles:' , 'private-suite'); ?></label><br />
	<input type="text" style="width: 27em;" id="protected_title_prefix" name="protected_title_prefix" value="<?php echo stripslashes(htmlentities($options['protected_title_prefix'])); ?>" /></p>
    
    <p><label for="private_suite_filter"><input type="checkbox" value="1" name="private_suite_filter" <?php checked($options['private_suite_filter']); ?> />
	<?php _e('Try to add private pages to <code>wp_list_pages()</code>, <code>wp_page_menu()</code>, and the Pages widget.', 'private-suite'); ?></label><br />
	<small><?php _e("This might not work as expected. If it doesn't, try using the <code>wp_list_private_pages()</code> template tag instead.", 'private-suite'); ?></small></p>
    </div>
    
    <div style="float: left; width: 40%;" id="categorydiv">
    	<h3><?php _e('Private Categories', 'private-suite'); ?></h3>
        <p><?php _e('Posts in this category will automatically have their visibility set to Private when they&#8217;re published.', 'private-suite'); ?></p>
        <div style="height: 15em; overflow-y: scroll; border: 1px solid #dfdfdf; padding: 0 1em; background: #fff; border-radius: 4px; -moz-border-radius: 4px; -webkit-border-radius: 4px;">
        <ul class="categorychecklist">
    		<?php wp_category_checklist(0, 0, $options['categories'], false, 0, false); ?>
        </ul>
        </div>
    </div>
    
    <div style="clear: both;"><!-- --></div>
    <div style="float: left; width: 40%; margin-right: 5%;">
    <div class="icon32" id="icon-edit-pages"><br/></div>
    <h2>Pages</h2>
    <p><select id="read_pages" name="read_pages">
			<option value="administrator" <?php selected('administrator', $options['read_pages']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['read_pages']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['read_pages']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['read_pages']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['read_pages']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="read_pages"><?php _e( 'and above can <strong>read</strong> private pages.' , 'private-suite'); ?></label>
	</p> 
    <p><select id="edit_pages" name="edit_pages">
			<option value="administrator" <?php selected('administrator', $options['edit_pages']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['edit_pages']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['edit_pages']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['edit_pages']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['edit_pages']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="edit_pages"><?php _e( 'and above can <strong>edit</strong> private pages.' , 'private-suite'); ?></label>
	</p> 
    <p><select id="delete_pages" name="delete_pages">
			<option value="administrator" <?php selected('administrator', $options['delete_pages']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['delete_pages']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['delete_pages']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['delete_pages']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['delete_pages']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="delete_pages"><?php _e( 'and above can <strong>delete</strong> private pages.' , 'private-suite'); ?></label>
	</p>
    </div>
    
    <div style="float: left; width: 40%;">
    <div class="icon32" id="icon-edit"><br/></div>
    <h2>Posts</h2>
    <p><select id="read_posts" name="read_posts">
			<option value="administrator" <?php selected('administrator', $options['read_posts']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['read_posts']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['read_posts']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['read_posts']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['read_posts']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="read_posts"><?php _e( 'and above can <strong>read</strong> private posts.' , 'private-suite'); ?></label>
	</p> 
    <p><select id="edit_posts" name="edit_posts">
			<option value="administrator" <?php selected('administrator', $options['edit_posts']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['edit_posts']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['edit_posts']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['edit_posts']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['edit_posts']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="edit_posts"><?php _e( 'and above can <strong>edit</strong> private posts.' , 'private-suite'); ?></label>
	</p> 
    <p><select id="delete_posts" name="delete_posts">
			<option value="administrator" <?php selected('administrator', $options['delete_posts']); ?>><?php _e('Administrators', 'private-suite'); ?></option>
			<option value="editor" <?php selected('editor', $options['delete_posts']); ?>><?php _e('Editors', 'private-suite'); ?></option>
            <option value="author" <?php selected('author', $options['delete_posts']); ?>><?php _e('Authors', 'private-suite'); ?></option>
            <option value="contributor" <?php selected('contributor', $options['delete_posts']); ?>><?php _e('Contributors', 'private-suite'); ?></option>
            <option value="subscriber" <?php selected('subscriber', $options['delete_posts']); ?>><?php _e('Subscribers', 'private-suite'); ?></option>
		</select>
        <label for="delete_posts"><?php _e( 'and above can <strong>delete</strong> private posts.' , 'private-suite'); ?></label>
	</p> 
    </div> 
    
    <input type="hidden" name="action" value="update" />
	<input type="hidden" name="page_options" value="private_suite" />
    
	<p class="submit" style="clear: both;">
	<input type="submit" name="submit" class="button-primary" value="<?php _e('Update Options', 'private-suite'); ?>" />
	</p>
	</form>
	</div>
<?php 
	} // if user can
} // end function private_suite_options() 


// i18n
$plugin_dir = basename(dirname(__FILE__)). '/languages';
load_plugin_textdomain( 'private-suite', 'wp-content/plugins/' . $plugin_dir, $plugin_dir );
?>